# NaviNIBS

NaviNIBS is a comprehensive toolbox for neuronavigated noninvasive brain stimulation. In its current form, NaviNIBS focuses on neuronavigation techniques for transcranial magnetic stimulation (TMS), allowing for precise and accurate positioning of the TMS coil over a subject’s head. The software includes key features such as MRI data visualization, target planning, subject head tracking, subject registration, coil tracking, and electrode digitization. Additionally, NaviNIBS supports addons for extending functionality, with addons already implemented for robotic coil positioning, data streaming, and integration of real-time electrophysiology data during neuronavigation.

See detailed documentation at [precisionneurolab.github.io/navinibs-docs](https://precisionneurolab.github.io/navinibs-docs).
